% TEST_APPENDEXTENSION Unitary tests for the appendextension sub-function
% Note:
%   The function needs to be imported at each test, because apparently Matlab
%   does not pass it from setupOnce() or setup().
%   For some reasons, the whole package needs to be imported, not just the
%   function under testing.

% -----
% Copyright 2022 Thomas Lambert <t.lambert@uliege.be>
% ULiege - Aeroelasticity and Experimental Aerodynamics
% Apache 2.0 License
% https://gitlab.uliege.be/am-dept/matlab_airfoil_toolbox
% ------------------------------------------------------------------------------


%% Main test function

function tests = test_appendextension

tests = functiontests(localfunctions);

end


%% Setup and teardown

function setupOnce(testCase)  % do not change function name

addpath('../.'); % Add repository to Matlab Path
addpath('./test_utils'); % Add utils to Matlab Path

% Set random number generator settings.
testCase.TestData.currentRNG = rng;

end

function teardownOnce(testCase)  % do not change function name

rmpath('../.'); % Remove repository from Matlab Path
rmpath('./test_utils'); % Remove utils from Matlab Path

% Restore the random number generator settings.
s = testCase.TestData.currentRNG;
rng(s)

end

function teardown(~)  % do not change function name

close all; % Close all figures that would have been openend

end


%% Test for correct output

function test_noExtension(testCase)
% Ensure that the function appends the extension if there is none

import af_tools.utils.*

string = 'test';
ext = '.m';

filename = [string,ext];

verifyEqual(testCase, appendextension(string, ext), filename)

end


function test_existExtension(testCase)
% Ensure that the function does not re-append the extension if it is already one

import af_tools.utils.*

string = 'test.m';
ext = '.m';

verifyEqual(testCase, appendextension(string, ext), string)

end