% TEST_SANITIZESTRING Unitary tests for the sanitizestring sub-function
% Note:
%   The function needs to be imported at each test, because apparently Matlab
%   does not pass it from setupOnce() or setup().
%   For some reasons, the whole package needs to be imported, not just the
%   function under testing.

% -----
% Copyright 2022 Thomas Lambert <t.lambert@uliege.be>
% ULiege - Aeroelasticity and Experimental Aerodynamics
% Apache 2.0 License
% https://gitlab.uliege.be/am-dept/matlab_airfoil_toolbox
% ------------------------------------------------------------------------------


%% Main test function

function tests = test_sanitizestring

tests = functiontests(localfunctions);

end


%% Setup and teardown

function setupOnce(testCase)  % do not change function name

addpath('../.'); % Add repository to Matlab Path
addpath('./test_utils'); % Add utils to Matlab Path

% Set random number generator settings.
testCase.TestData.currentRNG = rng;

end

function teardownOnce(testCase)  % do not change function name

rmpath('../.'); % Remove repository from Matlab Path
rmpath('./test_utils'); % Remove utils from Matlab Path

% Restore the random number generator settings.
s = testCase.TestData.currentRNG;
rng(s)

end

function teardown(~)  % do not change function name

close all; % Close all figures that would have been openend

end


%% Test for correct output

function test_removeLeadingSpaces(testCase)
% Ensure that the function trims the leading spaces

import af_tools.utils.*

string = '   test';

verifyEqual(testCase, sanitizestring(string), 'test')

end


function test_removeTrailingSpaces(testCase)
% Ensure that the function trims the trailing spaces

import af_tools.utils.*

string = 'test   ';

verifyEqual(testCase, sanitizestring(string), 'test')

end


function test_rmMultiSpaces(testCase)
% Ensure that the function removes contiguous spaces and change them by underscore

import af_tools.utils.*

string = 'str1    str2  str3';

verifyEqual(testCase, sanitizestring(string), 'str1_str2_str3')

end


function test_changePC(testCase)
% Ensure that the function changes % symbol

import af_tools.utils.*

string = '0%';

verifyEqual(testCase, sanitizestring(string), '0pc')

end