% TEST_VECTTOCOL Unitary tests for the vecttocol sub-function
% Note:
%   The function needs to be imported at each test, because apparently Matlab
%   does not pass it from setupOnce() or setup().
%   For some reasons, the whole package needs to be imported, not just the
%   function under testing.

% -----
% Copyright 2022 Thomas Lambert <t.lambert@uliege.be>
% ULiege - Aeroelasticity and Experimental Aerodynamics
% Apache 2.0 License
% https://gitlab.uliege.be/am-dept/matlab_airfoil_toolbox
% ------------------------------------------------------------------------------


%% Main test function

function tests = test_vecttocol

tests = functiontests(localfunctions);

end


%% Setup and teardown

function setupOnce(testCase)  % do not change function name

addpath('../.'); % Add repository to Matlab Path
addpath('./test_utils'); % Add utils to Matlab Path

% Set random number generator settings.
testCase.TestData.currentRNG = rng;

end

function teardownOnce(testCase)  % do not change function name

rmpath('../.'); % Remove repository from Matlab Path
rmpath('./test_utils'); % Remove utils from Matlab Path

% Restore the random number generator settings.
s = testCase.TestData.currentRNG;
rng(s)

end

function teardown(~)  % do not change function name

close all; % Close all figures that would have been openend

end


%% Test for correct output

function test_scalar(testCase)
% Ensure that the function outputs the same scalar

import af_tools.utils.*

scal = 0;

verifyEqual(testCase, vecttocol(scal), scal)

end


function test_rowVector(testCase)
% Ensure that the function outputs a column vector if we enter a row one

import af_tools.utils.*

rowVect = 1:10;

verifyEqual(testCase, vecttocol(rowVect), rowVect')

end


function test_colVect(testCase)
% Ensure that the function outputs the same vector if we enter a column one

import af_tools.utils.*

colVect = (1:10)';

verifyEqual(testCase, vecttocol(colVect), colVect)

end


function test_array(testCase)
% Ensure that the function outputs the same array if we enter an array

import af_tools.utils.*

array = rand(5);

verifyEqual(testCase, vecttocol(array), array)

end

